@@ -303,7 +303,7 @@ class SmartDriver(SeleniumDriverCore):
             they are a valid candidate. If none of them is of type input, we pick the one with maxIOU, otherwise we pick the input type,
             which is 90% of test cases.
             """
-            composite = filter(lambda x: x[0] > 0, composite)
+            composite = filter(lambda x: x[0] > 0.2, composite)
             composite = list(filter(lambda x: self._center_hit(new_box, x[1].rect), composite))
 
             if len(composite) == 0:
