@@ -602,18 +602,21 @@ class SeleniumDriverCore(object):
 
         needs_reload = False
         r = {'success': False}
+        has_training_data = False
         for _ in range(2):
             try:
-                r = requests.post(self.url + '/testcase/get_action_info', json=data, verify=False, timeout=3).json()
+                r = requests.post(self.url + '/testcase/get_action_info', json=data, verify=False, timeout=15).json()
                 break
-            except Exception:
+            except Exception as e:
+                log.error(e)
                 log.error('error getting test case actioninfo')
         if r['success']:
             box = r['predicted_element']
             needs_reload = r['needs_reload']
+            has_training_data = r['has_training_data']
         else:
             log.error(r.get('message', 'No error msg received'))
-        return box, needs_reload
+        return box, needs_reload, has_training_data
 
 
     def _test_case_upload_screenshot(self, label):
